#include <iostream>
#include "bass.h"

using namespace std;

/*	Name:	Bass Test
	Desc:	A simple sound system init, load, play, and unload example using the Bass Sound System
	Author:	James Jacoby
	Date:	12/05/2003

	Directions:
		This example imports bass.lib
		To link this library, go to project properties,
		select "Linker", then select "Import"
		Type bass.lib in the "additional dependencies" box

		Also make sure bass.dll is in your project directory root.

		You will need to download the Bass Library from http://www.un4seen.com/
*/
	
int main(void) {

	// Create an instance of a sound sample
	HSAMPLE sample = NULL;	

	cout << "Trying to play a sound..." << endl;

	// Initialize Bass System
	if( !BASS_Init(
				1,						// Default sound device
				44100,					// Frequency
				0,						// Fancy flags for cool fx (0=none)
				0,						// Window handle (0 for current foreground window)
				NULL ) ) 				// Class identifier of the object to create (NULL=defualt)
	{
		cout << "Unable to init" << endl;
		return -1;
	}


	// Load the sample (wav) from a file
	sample = BASS_SampleLoad(	
				FALSE,					// Don't load from memory
				"engine.wav",			// Path to file
				0,						// Offset (0=none)
				0,						// Length (0=all of file)
				3,						// Max number of simultaneous playbacks (for this sample)
				BASS_SAMPLE_OVER_POS );	// Flags BASS_SAMPLE_OVER_POS tells it to overrid the 
										// longest playing sample when it runs out of space
	// Check for error
	if( !sample ) {
		cout << "Something bad happened while loading the sample" << endl;
		return -1;
	}

	// Play the sound
	if( !BASS_SamplePlay( sample ) ) {
		cout << "Unable to play sound" << endl;
		return -1;
	}

	char wait;
	cout << "Type something and press enter to exit";
	cin >> wait;


	// Free
	BASS_Free();

	return 0;

}